# TOPSIS_Aashima_101803213
Technique for Order Preference by Similarity to Ideal Solution (TOPSIS) originated in the 1980s as a multi-criteria decision making method. TOPSIS chooses the alternative of shortest Euclidean distance from the ideal solution, and greatest distance from the negative-ideal solution. 

## Installation 
'''pip install TOPSIS_Aashima_101803213'''

## How to use it?
Open terminal and type PYTHON TOPSIS along with input file path whose topsis value and rank you wanted to find
i.e python TOPSIS "data.csv" 

Please make sure to update tests as appropriate.
https://github.com/aashima99/TOPSIS \#\# License
[MIT](https://choosealicense.com/licenses/mit/)

## License
©  2020 Aashima Tandon
This repository is licensed under the MIT license. 
See LICENSE for details